install.packages("text2vec")
install.packages("data.table")

library(text2vec)
# a seconda del tipo di analisi che effettuiamo con text2vec, può risultare comodo traslare i dati in formato data.table, ma in questo esempio non ne abbiamo bisogno
library(data.table)

# creiamo un vettore di frasi positive
pos <- rbind(c("You are awesome and I love you so much", "positive"),
             c("I love traveling, this place is so beautiful", "positive"),
             c("I liked this movie so much", "positive"),
             c("Your pet is adorable", "positive"),
             c("This book is amazing", "positive"),
             c("This is my favourite movie", "positive"),
             c("He is undoubtedly a great actor", "positive"),
             c("Wonderful movie, is really incredible", "positive"),
             c("The director is really experienced", "positive"),
             c("I cannot tell you how much I enjoyed during this traveling", "positive"))

# creiamo un vettore di frasi negative
neg <- rbind(c("I hate and hate and hate. So angry. Die!", "negative"),
             c("Impressed and amazed: you are peerless in your achievement of unparalleled mediocrity", "negative"),
             c("This is possibly the worst movie even made", "negative"),
             c("I don t like it, is boring", "negative"),
             c("Don t waste your time and money", "negative"),
             c("Very bad acting, very boring, I am so disappointed!", "negative"),
             c("It is garbage, it is so trash", "negative"),
             c("This book is simply terrible, I am horrified", "negative"),
             c("So many thing are so idiotic that it pissed me off", "negative"),
             c("I thought the film was totally awful, bad script and acting", "negative"))

# creiamo un vettore di test che contiene sia frasi positive che negative
test <- rbind(c("It was a great experience", "positive"),
              c("Bad acting, bad music and especially bad taste", "negative"),
              c("This is the best movie created so far", "positive"),
              c("It's a waste of time", "negative"),
              c("Well directed, well produced, I like it", "positive"),
              c("I love the photography and the script is amazing", "positive"),
              c("Truly disappointed from this product", "negative"),
              c("All the characters are beautifully executed", "positive"),
              c("Unfortunately I didn't like it at all", "negative"),
              c("Horrid acting and mediocre script, I'm unhappy", "negative"))


# creiamo un oggetto unico
tot <- rbind(pos, neg, test)

# trasformiamo la matrice in un dataframe
tot <- as.data.frame(tot)

# rinominiamo le colonne 
colnames(tot) <- c("text", "sent")

# estraiamo tutti gli item contrassegnati come positivi e quelli contrassegnati come negativi
pos <- subset(tot, sent=="positive")
neg <- tot[which(tot$sent== "negative"),]

# modifichiamo la natura dei nostri oggetti in caratteri
pos$text <- as.character(pos$text)
pos$sent <- as.character(pos$sent)

neg$text <- as.character(neg$text)
neg$sent <- as.character(neg$sent)


# rimuoviamo le stopwords tramite tm
library(tm)
pos$text <- removeWords(pos$text, stopwords("english"))
neg$text <- removeWords(neg$text, stopwords("english"))

# possiamo anche creare un'ulteriore lista di stopwords
stop_words <- c("i", "me", "my", "myself", "we", "our", "ours", "ourselves", "you", "your", "yours")

# possiamo creare una funzione per lo stemming da aggiungere al preprocessing
stem_tokenizer <- function(x) {
        word_tokenizer(x) %>% lapply(SnowballC::wordStem('en'))
        }


# processiamo il testo degli item positivi convertendolo in un formato accettato da text2vec
pos_preproc <- itoken(pos$text, 
                  preprocessor = tolower, 
                  tokenizer = word_tokenizer,
                  stemmer = stem_tokenizer,
                  ids = NULL, 
                  progressbar = FALSE)

# creiamo un vocabolario di termini positivi
pos_voc <- create_vocabulary(pos_preproc)

# processiamo il testo degli item negativi convertendolo in un formato accettato da text2vec
neg_preproc <- itoken(neg$text, 
                      preprocessor = tolower, 
                      tokenizer = word_tokenizer,
                      stemmer = stem_tokenizer,
                      ids = NULL,
                      progressbar = FALSE)

# creiamo un vocabolario di termini negativi
neg_voc <- create_vocabulary(neg_preproc)

### cambiamo oggetto e ricarichiamo alice per visualizzare gli n-gram
alice <- scan("/Users/valentinaporcu/R_test/text/alice.txt", what="character", sep="\n")

alice <- itoken(alice, 
                      preprocessor = tolower, 
                      tokenizer = word_tokenizer,
                      stemmer = stem_tokenizer,
                      ids = NULL, 
                      progressbar = FALSE)


al_ngram <- create_vocabulary(alice, ngram = c(ngram_min = 1L, ngram_max = 3L), stopwords = character(0), sep_ngram = "_")

