install.packages(c("NLP", "openNLP", "RWeka", "qdap", "rJava"))

library(openNLP)
library(NLP)
library(magrittr)

# importiamo il file
s <- readLines("/Users/valentinaporcu/R_test/the100/txt/George\ Marshall\ -\ The\ Marshall\ Plan.txt")

# rimuoviamo gli spazi vuoti
s <- paste(s, collapse = " ")

# convertiamo in stringa
s <- as.String(s)

# creiamo gli annotatori
word_ann <- Maxent_Word_Token_Annotator()
sent_ann <- Maxent_Sent_Token_Annotator()
pos_ann <- Maxent_POS_Tag_Annotator()

# creiamo gli oggetti annotati
a2 <- annotate(s, list(sent_ann, word_ann))
a3 <- annotate(s, pos_ann, a2)
a4 <- AnnotatedPlainTextDocument(s, a2)

# verifichiamo alcune frasi e parole dell'oggetto a4
sents(a4) %>% head(2)
words(a4) %>% head(10)

# l'oggetto che creiamo contiene il testo diviso per frasi
ann <- annotate(a4, pos_ann, a2)

# possiamo visualizzare le posizioni delle frasi anche in questo modo
head(annotate(s, Maxent_POS_Tag_Annotator(probs = TRUE), a2))


## Determiniamo la funzione di ogni termine 
a3w <- subset(a3, type == "word")

head(a3w)

tags <- sapply(a3w$features, `[[`, "POS")
table(tags)



# installiamo il dizionario per estrarre luoghi, organizzazioni e persone
install.packages("openNLPmodels.en", repos = "http://datacube.wu.ac.at/", type = "source")

person_ann <- Maxent_Entity_Annotator(kind = "person")
location_ann <- Maxent_Entity_Annotator(kind = "location")
organization_ann <- Maxent_Entity_Annotator(kind = "organization")

# racchiudiamo le entità in un unico oggetto
pipeline <- list(sent_ann,
                 word_ann,
                 person_ann,
                 location_ann,
                 organization_ann)


ann1 <- annotate(s, pipeline)
doc <- AnnotatedPlainTextDocument(s, ann1)


entities <- function(doc, kind) {
        s <- doc$content
        a <- annotations(doc)[[1]]
        if(hasArg(kind)) {
                k <- sapply(a$features, `[[`, "kind")
                s[a[k == kind]]
        } else {
                s[a[a$type == "entity"]]
        }
}

# visualizziamo le entità del nostro testo iniziale
entities(doc, kind = "person")
entities(doc, kind = "location")
entities(doc, kind = "organization")
